@@ -1,5 +1,6 @@
 __all__ = [
     "SellerBarcodeAPI",
+    "SellerBetaAPI",
     "SellerCategoryAPI",
     "SellerFBSAPI",
     "SellerPricesAndStocksAPI",
@@ -9,6 +10,7 @@ __all__ = [
 
 from .attributes_and_characteristics import SellerCategoryAPI
 from .barcodes import SellerBarcodeAPI
+from .beta import SellerBetaAPI
 from .fbs import SellerFBSAPI
 from .prices_and_stocks import SellerPricesAndStocksAPI
 from .products import SellerProductAPI
