@@ -1,6 +1,8 @@
-from ..core import APIManager
+from ..core import APIManager, method_rate_limit
 from ..schemas.fbs import PostingFBSUnfulfilledListRequest, PostingFBSUnfulfilledListResponse, PostingFBSListResponse, \
-    PostingFBSListRequest, PostingFBSGetRequest, PostingFBSGetResponse
+    PostingFBSListRequest, PostingFBSGetRequest, PostingFBSGetResponse, PostingFBSGetByBarcodeResponse, \
+    PostingFBSGetByBarcodeRequest, PostingFBSMultiBoxQtySetResponse, PostingFBSMultiBoxQtySetRequest, \
+    PostingFBSProductChangeRequest, PostingFBSProductChangeResponse
 
 
 class SellerFBSAPI(APIManager):
@@ -162,6 +164,7 @@ class SellerFBSAPI(APIManager):
         )
         return PostingFBSListResponse(**response)
 
+    @method_rate_limit(limit_requests=2, interval_seconds=1)
     async def posting_fbs_get(
             self: "SellerFBSAPI",
             request: PostingFBSGetRequest
@@ -169,6 +172,7 @@ class SellerFBSAPI(APIManager):
         """Метод для получения информации об отправлении FBS по его номеру.
 
         Notes:
+            • Метод часто возвращает 429 (TooManyRequestsError), поэтому установлено ограничение 2 запроса в секунду (экспериментальное значение).
             • Чтобы получать актуальную дату отгрузки, регулярно обновляйте информацию об отправлениях или подключите пуш-уведомления.
             • Для получения дополнительных данных используйте параметр `with_` в запросе.
 
@@ -213,4 +217,126 @@ class SellerFBSAPI(APIManager):
             endpoint="posting/fbs/get",
             json=request.model_dump(by_alias=True)
         )
-        return PostingFBSGetResponse(**response)
\ No newline at end of file
+        return PostingFBSGetResponse(**response)
+
+    async def posting_fbs_get_by_barcode(
+            self: "SellerFBSAPI",
+            request: PostingFBSGetByBarcodeRequest
+    ) -> PostingFBSGetByBarcodeResponse:
+        """Метод для получения информации об отправлении FBS по штрихкоду.
+
+        Notes:
+            • Штрихкод отправления можно получить с помощью методов posting_fbs_get(), posting_fbs_list(), posting_fbs_unfulfilled_list() в массиве barcodes
+            • Метод возвращает основную информацию об отправлении: статус, данные о заказе, товары и штрихкоды.
+            • Для получения дополнительных данных (финансовой информации, аналитики и т.д.) используйте метод posting_fbs_get().
+
+        References:
+            https://docs.ozon.ru/api/seller/?__rr=1#operation/PostingAPI_GetFbsPostingByBarcode
+
+        Args:
+            request: Запрос на получение информации об отправлении по штрихкоду по схеме `PostingFBSGetByBarcodeRequest`
+
+        Returns:
+            Информация об отправлении FBS по схеме `PostingFBSGetByBarcodeResponse`
+
+        Examples:
+            async with SellerAPI(client_id, api_key) as api:
+                result = await api.posting_fbs_get_by_barcode(
+                    PostingFBSGetByBarcodeRequest(
+                        barcode="20325804886000"
+                    )
+                )
+        """
+        response = await self._request(
+            method="post",
+            api_version="v2",
+            endpoint="posting/fbs/get-by-barcode",
+            json=request.model_dump()
+        )
+        return PostingFBSGetByBarcodeResponse(**response["result"])
+
+    async def posting_fbs_multiboxqty_set(
+            self: "SellerFBSAPI",
+            request: PostingFBSMultiBoxQtySetRequest
+    ) -> PostingFBSMultiBoxQtySetResponse:
+        """Метод для передачи количества коробок для отправлений, в которых есть многокоробочные товары.
+
+        Notes:
+            • Метод используется при работе по схеме rFBS Агрегатор — с доставкой партнёрами Ozon.
+            • Используется только для многокоробочных отправлений, где товары упакованы в несколько коробок.
+            • Количество коробок должно быть целым положительным числом.
+            • После успешного выполнения метода система учитывает указанное количество коробок при дальнейшей обработке отправления.
+
+        References:
+            https://docs.ozon.ru/api/seller/?__rr=1#operation/PostingAPI_PostingMultiBoxQtySetV3
+
+        Args:
+            request: Запрос на указание количества коробок для многокоробочного отправления по схеме `PostingFBSMultiBoxQtySetRequest`
+
+        Returns:
+            Результат выполнения операции по схеме `PostingFBSMultiBoxQtySetResponse`
+
+        Examples:
+            Пример с проверкой результата:
+                async with SellerAPI(client_id, api_key) as api:
+                    result = await api.posting_multiboxqty_set(
+                        PostingFBSMultiBoxQtySetRequest(
+                            posting_number="57195475-0050-3",
+                            multi_box_qty=3
+                        )
+                    )
+
+                    if result.result.result:
+                        print("Количество коробок успешно передано")
+                    else:
+                        print("Произошла ошибка при указании количества коробок")
+        """
+        response = await self._request(
+            method="post",
+            api_version="v3",
+            endpoint="posting/fbs/multi-box-qty/set",
+            json=request.model_dump()
+        )
+        return PostingFBSMultiBoxQtySetResponse(**response)
+
+    async def posting_fbs_product_change(
+            self: "SellerFBSAPI",
+            request: PostingFBSProductChangeRequest
+    ) -> PostingFBSProductChangeResponse:
+        """Метод для добавления веса для весовых товаров в отправлении FBS.
+
+        Notes:
+            • Метод используется для указания фактического веса весовых товаров в отправлении.
+            • Можно указать вес для нескольких товаров в одном запросе.
+            • После указания веса система пересчитывает стоимость доставки и другие параметры отправления.
+
+        References:
+            https://docs.ozon.ru/api/seller/?__rr=1#operation/PostingAPI_ChangeFbsPostingProduct
+
+        Args:
+            request: Запрос на добавление веса для весовых товаров в отправлении по схеме `PostingFBSProductChangeRequest`
+
+        Returns:
+            Результат выполнения операции по схеме `PostingFBSProductChangeResponse`
+
+        Examples:
+            async with SellerAPI(client_id, api_key) as api:
+                result = await api.posting_fbs_product_change(
+                    PostingFBSProductChangeRequest(
+                        posting_number="33920158-0006-1",
+                        items=[
+                            PostingFBSProductChangeRequestItem(
+                                sku=1231428352,
+                                weight_real=0.3
+                            )
+                        ]
+                    )
+                )
+        """
+        response = await self._request(
+            method="post",
+            api_version="v2",
+            endpoint="posting/fbs/product/change",
+            json=request.model_dump(by_alias=True)
+        )
+        return PostingFBSProductChangeResponse(**response)
\ No newline at end of file
