@@ -11,7 +11,8 @@ __all__ = [
     "PostingFBSLegalInfo",
     "PostingFBSOptional",
     "PostingFBSPosting",
-    "PostingFBSProducts",
+    "PostingFBSProduct",
+    "PostingFBSProductDetailed",
     "PostingFBSRequirements",
     "PostingFBSTariffication",
     "PostingFBSFilterWith",
@@ -29,7 +30,7 @@ from .posting__financial_data_products import PostingFBSFinancialDataProducts
 from .posting__legal_info import PostingFBSLegalInfo
 from .posting__optional import PostingFBSOptional
 from .posting__posting import PostingFBSPosting
-from .posting__products import PostingFBSProducts
+from .posting__product import PostingFBSProductDetailed, PostingFBSProduct
 from .posting__requirements import PostingFBSRequirements
 from .posting__tariffication import PostingFBSTariffication
 from .posting__addressee import PostingFBSAddressee
\ No newline at end of file
